@@ -8,6 +8,9 @@ function on_error() {
 }
 trap on_error ERR
 
+echo -n "Build (dist) Starting at "
+date
+
 function qpushd() { pushd "$@" >/dev/null; }
 function qpopd() { popd >/dev/null; }
 function unix_path() { echo "$*" | sed 's,^\([A-Za-z]\):,/\1,;s,\\,/,g'; }
@@ -25,6 +28,7 @@ add_step dist_prepare
 add_step dist_regex
 add_step dist_autotools
 add_step dist_guile
+add_step dist_webkit
 add_step dist_gnome
 add_step dist_isocodes
 add_step dist_pcre
@@ -38,7 +42,6 @@ add_step dist_gwenhywfar
 add_step dist_ktoblzcheck
 add_step dist_aqbanking
 add_step dist_libdbi
-add_step dist_webkit
 add_step dist_gnucash
 add_step dist_finish
 
@@ -55,6 +58,9 @@ restore_msys "$_PID"
 qpopd
 
 
+echo -n "Build (dist) Finished at "
+date
+
 ### Local Variables: ***
 ### sh-basic-offset: 4 ***
 ### indent-tabs-mode: nil ***
