@@ -118,8 +118,12 @@
   (vector-ref option 8))
 (define (gnc:option-scm->kvp option)
   (vector-ref option 9))
+(define (gnc:set-option-scm->kvp option v)
+  (vector-set! option 9 v))
 (define (gnc:option-kvp->scm option)
   (vector-ref option 10))
+(define (gnc:set-option-kvp->scm option v)
+  (vector-set! option 10 v))
 (define (gnc:option-value-validator option)  
   (vector-ref option 11))
 (define (gnc:option-data option)
