@@ -270,8 +270,10 @@ gnc_sql_load( GncSqlBackend* be, /*@ dependent @*/ QofBook *book, QofBackendLoad
 
     be->loading = FALSE;
 
-    // Mark the book as clean
-    qof_book_mark_saved( book );
+    /* Mark the sessoion as clean -- though it should never be marked
+     * dirty with this backend
+     */
+    qof_book_mark_session_saved( book );
     finish_progress( be );
 
     LEAVE( "" );
@@ -545,8 +547,10 @@ gnc_sql_sync_all( GncSqlBackend* be, /*@ dependent @*/ QofBook *book )
     {
         be->is_pristine_db = FALSE;
 
-        // Mark the book as clean
-        qof_book_mark_saved( book );
+        /* Mark the session as clean -- though it shouldn't ever get
+	 * marked dirty with this backend
+	 */
+        qof_book_mark_session_saved( book );
     }
     else
     {
@@ -631,8 +635,8 @@ gnc_sql_commit_edit( GncSqlBackend *be, QofInstance *inst )
     // The engine has a PriceDB object but it isn't in the database
     if ( strcmp( inst->e_type, "PriceDB" ) == 0 )
     {
+        qof_book_mark_session_saved( be->primary_book );
         qof_instance_mark_clean( inst );
-        qof_book_mark_saved( be->primary_book );
         return;
     }
 
@@ -672,8 +676,8 @@ gnc_sql_commit_edit( GncSqlBackend *be, QofInstance *inst )
         (void)gnc_sql_connection_rollback_transaction( be->conn );
 
         // Don't let unknown items still mark the book as being dirty
+        qof_book_mark_session_saved( be->primary_book );
         qof_instance_mark_clean(inst);
-        qof_book_mark_saved( be->primary_book );
         LEAVE( "Rolled back - unknown object type" );
         return;
     }
@@ -689,8 +693,8 @@ gnc_sql_commit_edit( GncSqlBackend *be, QofInstance *inst )
 
     (void)gnc_sql_connection_commit_transaction( be->conn );
 
+    qof_book_mark_session_saved( be->primary_book );
     qof_instance_mark_clean(inst);
-    qof_book_mark_saved( be->primary_book );
 
     LEAVE( "" );
 }
