@@ -207,8 +207,8 @@ gnc_vendor_window_ok_cb (GtkWidget *widget, gpointer data)
     if (check_entry_nonempty (vw->dialog, vw->company_entry,
                               _("You must enter a company name. "
                                 "If this vendor is an individual (and not a company) "
-                                "you should set the \"company name\" and \"contact name\" "
-                                "the same.")))
+                                "you should enter the same value for:\nIdentification "
+                                "- Company Name, and\nPayment Address - Name.")))
         return;
 
     /* Make sure we have an address */
@@ -225,8 +225,7 @@ gnc_vendor_window_ok_cb (GtkWidget *widget, gpointer data)
     /* Check for valid id and set one if necessary */
     if (safe_strcmp (gtk_entry_get_text (GTK_ENTRY (vw->id_entry)), "") == 0)
     {
-        string = g_strdup_printf ("%.6" G_GINT64_FORMAT,
-                                  gncVendorNextID(vw->book));
+        string = gncVendorNextID(vw->book);
         gtk_entry_set_text (GTK_ENTRY (vw->id_entry), string);
         g_free(string);
     }
