@@ -409,20 +409,23 @@ gnc_ui_to_account(AccountWindow *aw)
     gtk_text_buffer_get_end_iter (aw->notes_text_buffer, &end);
     string = gtk_text_buffer_get_text (aw->notes_text_buffer, &start, &end, FALSE);
     old_string = xaccAccountGetNotes (account);
-    if (safe_strcmp (string, old_string) != 0)
+    if (null_strcmp (string, old_string) != 0)
         xaccAccountSetNotes (account, string);
 
     flag =
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (aw->tax_related_button));
-    xaccAccountSetTaxRelated (account, flag);
+    if (xaccAccountGetTaxRelated (account) != flag)
+	xaccAccountSetTaxRelated (account, flag);
 
     flag =
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (aw->placeholder_button));
-    xaccAccountSetPlaceholder (account, flag);
+    if (xaccAccountGetPlaceholder (account) != flag)
+	xaccAccountSetPlaceholder (account, flag);
 
     flag =
         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (aw->hidden_button));
-    xaccAccountSetHidden (account, flag);
+    if (xaccAccountGetHidden (account) != flag)
+	xaccAccountSetHidden (account, flag);
 
     parent_account = gnc_tree_view_account_get_selected_account (GNC_TREE_VIEW_ACCOUNT (aw->parent_tree));
 
@@ -1539,10 +1542,10 @@ gnc_ui_new_account_window_internal (QofBook *book,
                                     Account *base_account,
                                     gchar **subaccount_names,
                                     GList *valid_types,
-                                    gnc_commodity * default_commodity,
+                                    const gnc_commodity * default_commodity,
                                     gboolean modal)
 {
-    gnc_commodity *commodity, *parent_commodity;
+    const gnc_commodity *commodity, *parent_commodity;
     AccountWindow *aw;
     Account *account;
     GList *list;
@@ -1607,7 +1610,7 @@ gnc_ui_new_account_window_internal (QofBook *book,
         commodity = NULL;
     }
     gnc_general_select_set_selected (GNC_GENERAL_SELECT (aw->commodity_edit),
-                                     commodity);
+                                     (gpointer) commodity);
     gnc_account_commodity_from_type (aw, FALSE);
 
     if (base_account == NULL)
@@ -1704,7 +1707,7 @@ gnc_ui_new_accounts_from_name_window_with_types (const char *name,
 Account *
 gnc_ui_new_accounts_from_name_with_defaults (const char *name,
         GList *valid_types,
-        gnc_commodity * default_commodity,
+        const gnc_commodity * default_commodity,
         Account * parent)
 {
     QofBook *book;
