@@ -141,6 +141,9 @@ typedef struct
     gboolean show_hidden;
 } AccountTreeFilterInfo;
 
+static AccountTreeFilterInfo *from_info = NULL;
+static AccountTreeFilterInfo *to_info   = NULL;
+
 struct _acct_list_item
 {
     char *acct_full_name;
@@ -160,7 +163,7 @@ static void gnc_transfer_dialog_set_selected_account (XferDialog *dialog,
         XferDirection direction);
 void gnc_xfer_dialog_response_cb (GtkDialog *dialog, gint response, gpointer data);
 void gnc_xfer_dialog_close_cb(GtkDialog *dialog, gpointer data);
-static gboolean gnc_xfer_dialog_show_inc_exp_visible_cb (Account *account,
+static gboolean gnc_xfer_dialog_inc_exp_filter_func (Account *account,
         gpointer data);
 
 /** Implementations **********************************************/
@@ -231,15 +234,17 @@ gnc_xfer_dialog_update_price (XferDialog *xferData)
 static void
 gnc_xfer_dialog_toggle_cb(GtkToggleButton *button, gpointer data)
 {
-    AccountTreeFilterInfo info;
+    AccountTreeFilterInfo *info;
+    GncTreeViewAccount* treeview = GNC_TREE_VIEW_ACCOUNT (data);
 
-    info.show_inc_exp = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
-    info.show_hidden = FALSE;
+    info = g_object_get_data (G_OBJECT(treeview), "filter-info");
+    if (info)
+    {
+        info->show_inc_exp = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
+        info->show_hidden = FALSE;
 
-    gnc_tree_view_account_set_filter (GNC_TREE_VIEW_ACCOUNT (data),
-                                      gnc_xfer_dialog_show_inc_exp_visible_cb,
-                                      &info,  /* user data */
-                                      NULL    /* destroy callback */);
+        gnc_tree_view_account_refilter (treeview);
+    }
 }
 
 static gboolean
@@ -461,7 +466,7 @@ gnc_xfer_dialog_to_tree_selection_changed_cb (GtkTreeSelection *selection, gpoin
 }
 
 static gboolean
-gnc_xfer_dialog_show_inc_exp_visible_cb (Account *account,
+gnc_xfer_dialog_inc_exp_filter_func (Account *account,
         gpointer data)
 {
     AccountTreeFilterInfo* info;
@@ -493,7 +498,7 @@ gnc_xfer_dialog_fill_tree_view(XferDialog *xferData,
     GtkWidget *button;
     GtkTreeSelection *selection;
     gboolean  use_accounting_labels;
-    AccountTreeFilterInfo info;
+    AccountTreeFilterInfo *info;
 
     use_accounting_labels = gnc_gconf_get_bool(GCONF_GENERAL,
                             KEY_ACCOUNTING_LABELS, NULL);
@@ -528,17 +533,22 @@ gnc_xfer_dialog_fill_tree_view(XferDialog *xferData,
                                               "right_trans_window" : "left_trans_window");
     }
 
+
+    if (direction == XFER_DIALOG_TO)
+        info = to_info;
+    else
+        info = from_info;
+
     tree_view = GTK_TREE_VIEW(gnc_tree_view_account_new(FALSE));
     gtk_container_add(GTK_CONTAINER(scroll_win), GTK_WIDGET(tree_view));
-    info.show_inc_exp = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
-    info.show_hidden = FALSE;
+    info->show_inc_exp = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
+    info->show_hidden = FALSE;
     gnc_tree_view_account_set_filter (GNC_TREE_VIEW_ACCOUNT (tree_view),
-                                      gnc_xfer_dialog_show_inc_exp_visible_cb,
-                                      &info,  /* user data */
+                                      gnc_xfer_dialog_inc_exp_filter_func,
+                                      info,  /* user data */
                                       NULL    /* destroy callback */);
+    g_object_set_data (G_OBJECT(tree_view), "filter-info", info);
 
-    /* Have to force the filter once. Alt is to show income/expense by default. */
-    gnc_tree_view_account_refilter (GNC_TREE_VIEW_ACCOUNT (tree_view));
     gtk_widget_show(GTK_WIDGET(tree_view));
     g_signal_connect (G_OBJECT (tree_view), "key-press-event",
                       G_CALLBACK (gnc_xfer_dialog_key_press_cb), NULL);
@@ -1759,6 +1769,9 @@ gnc_xfer_dialog_create(GtkWidget *parent, XferDialog *xferData)
         GtkWidget *label;
         gchar *text;
 
+        to_info   = g_new0(AccountTreeFilterInfo, 1);
+        from_info = g_new0(AccountTreeFilterInfo, 1);
+
         gnc_xfer_dialog_fill_tree_view (xferData, XFER_DIALOG_TO);
         gnc_xfer_dialog_fill_tree_view (xferData, XFER_DIALOG_FROM);
 
@@ -1884,6 +1897,8 @@ close_handler (gpointer user_data)
     gtk_widget_hide (dialog);
     gnc_xfer_dialog_close_cb(GTK_DIALOG(dialog), xferData);
     gtk_widget_destroy (dialog);
+    g_free (to_info);
+    g_free (from_info);
     LEAVE(" ");
 }
 
