@@ -213,6 +213,7 @@ void gnc_xfer_dialog_set_txn_cb(XferDialog *xferData,
 */
 gboolean gnc_xfer_dialog_run_exchange_dialog(
     XferDialog *xfer, gnc_numeric *exch_rate, gnc_numeric amount,
-    Account *reg_acc, Transaction *txn, gnc_commodity *xfer_com);
+    Account *reg_acc, Transaction *txn, gnc_commodity *xfer_com,
+    gboolean expanded);
 
 #endif
