@@ -292,6 +292,7 @@ static gchar *
 gnc_history_generate_label (int index, const gchar *filename)
 {
     gchar *label, *result;
+    gchar **splitlabel;
 
     if ( gnc_uri_is_file_uri ( filename ) )
     {
@@ -306,6 +307,12 @@ gnc_history_generate_label (int index, const gchar *filename)
         label = gnc_uri_normalize_uri ( filename, FALSE );
     }
 
+    /* Escape '_' characters */
+    splitlabel = g_strsplit ( label, "_", 0);
+    g_free (label);
+    label = g_strjoinv ( "__", splitlabel);
+    g_strfreev (splitlabel);
+
     result = g_strdup_printf ( "_%d %s", (index + 1) % 10, label);
     g_free ( label );
     return result;
@@ -718,8 +725,7 @@ gnc_plugin_file_history_cmd_open_file (GtkAction *action,
     filename = g_object_get_data(G_OBJECT(action), FILENAME_STRING);
     gnc_window_set_progressbar_window (GNC_WINDOW(data->window));
     /* also opens new account page */
-    if (!gnc_file_open_file (filename))
-        gnc_history_remove_file (filename);
+    gnc_file_open_file (filename);
     gnc_window_set_progressbar_window (NULL);
 }
 
