@@ -27,7 +27,7 @@
 #ifndef __GNC_PLUGIN_BUDGET_H
 #define __GNC_PLUGIN_BUDGET_H
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include "gnc-plugin.h"
 #include "gnc-budget.h"
 
