@@ -34,6 +34,8 @@ typedef struct _genimportsettings GNCImportSettings;
  *   Getter/Setter Functions for the Data Types.
  ************************************************************************/
 
+/** The GConf section of the importer */
+#define GCONF_IMPORT_SECTION "dialogs/import/generic_matcher"
 
 
 /** Allocates a new GNCImportSettings object, and initialize it with
