@@ -2,6 +2,9 @@
 ;;
 ;; This file was copied from the file txf.scm by  Richard -Gilligan- Uschold
 ;;
+;; In part English text with German text replaced and completed
+;; for GnuCash Vers. 2.4.0 in Dezember 2010 by FJSW - Franz Stoll
+;;
 ;; Originally, these were meant to print Tax related accounts and
 ;; exports TXF files for import to TaxCut, TurboTax, etc.  for the US
 ;; tax TXF format. I modified this heavily so that it might become
@@ -38,7 +41,7 @@
 ;;
 ;; NOTE: setting of specific dates is squirly! and seems to be
 ;; current-date dependant!  Actually, time of day dependant!  Just
-;; after midnight gives diffenent dates than just before!  Referencing
+;; after midnight gives different dates than just before!  Referencing
 ;; all times to noon seems to fix this.  Subtracting 1 year sometimes
 ;; subtracts 2!  see "(to-value"
 
@@ -232,11 +235,11 @@
                              (let* ((acc (cadr x))
                                     (txf (gnc:account-get-txf acc)))
                                (cons (string-append 
-                                      "Code \"" 
+                                      "Kennzahl \"" 
                                       (symbol->string
                                        (gnc:account-get-txf-code acc))
-                                      "\" has duplicates in "
-                                      (number->string cnt) " accounts:")
+                                      "\" hat Duplikate in "
+                                      (number->string cnt) " Konten:")
                                      (map gnc-account-get-full-name
                                           (cdr x))))
                              '())))
@@ -832,7 +835,10 @@
                    (gnc:html-markup
                     "blue"
                     (gnc:html-markup-p
-                     (_ "Blue items are exportable to a German Tax XML file. Press Export to actually export them."))))))
+                     "Blaue Posten können in eine XML-Datei und diese mit der Software \"Winston\" zu ELSTER exportiert werden.<br>
+Diese XML-Datei enthält dann die geschlüsselten USt-Kennzahlen und zu diesen die summierten Werte für den ELSTER-Export.<br>
+Bei Umsätzen werden nur voll Beträge ausgewiesen, bei Steuerkennzahlen auch die Dezimalstellen, aber ohne Komma.<br>
+Klicken Sie auf »Exportieren« , um den Export durchzuführen.")))))
             
             (txf-print-dups doc)
             
@@ -847,8 +853,8 @@
                  doc
                  (gnc:make-html-text
                   (gnc:html-markup-p
-                   (_ "No Tax Related accounts were found.  Go to the\
- Edit->Tax Options dialog to set up tax-related accounts.")))))
+         "Keine Steuer-relevanten Konten gefunden.<br>
+Gehen Sie zu Bearbeiten -> Optionen Steuerbericht, um Konten entsprechend einzurichten."))))
 
 	    (gnc:report-finished)
             doc)))))
