@@ -1,21 +1,21 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; html-linechart.scm : generate HTML programmatically, with support
-;; for simple style elements. 
+;; for simple style elements.
 ;; Copyright 2008 Sven Henkel <shenkel@gmail.com>
-;; 
+;;
 ;; Adapted from html-barchart.scm which is
 ;; Copyright 2000 Bill Gribble <grib@gnumatic.com>
 ;;
-;; This program is free software; you can redistribute it and/or    
-;; modify it under the terms of the GNU General Public License as   
-;; published by the Free Software Foundation; either version 2 of   
-;; the License, or (at your option) any later version.              
-;;                                                                  
-;; This program is distributed in the hope that it will be useful,  
-;; but WITHOUT ANY WARRANTY; without even the implied warranty of   
-;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the    
-;; GNU General Public License for more details.                     
-;;                                                                  
+;; This program is free software; you can redistribute it and/or
+;; modify it under the terms of the GNU General Public License as
+;; published by the Free Software Foundation; either version 2 of
+;; the License, or (at your option) any later version.
+;;
+;; This program is distributed in the hope that it will be useful,
+;; but WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+;; GNU General Public License for more details.
+;;
 ;; You should have received a copy of the GNU General Public License
 ;; along with this program; if not, contact:
 ;;
@@ -26,15 +26,15 @@
 
 (define <html-linechart>
   (make-record-type "<html-linechart>"
-                    '(width 
-                      height 
-                      title 
-                      subtitle 
+                    '(width
+                      height
+                      title
+                      subtitle
                       x-axis-label
                       y-axis-label
                       col-labels
-                      row-labels 
-                      col-colors 
+                      row-labels
+                      col-colors
                       legend-reversed?
                       row-labels-rotated?
                       stacked?
@@ -43,27 +43,28 @@
                       minor-grid?
                       data
                       button-1-line-urls
-                      button-2-line-urls 
+                      button-2-line-urls
                       button-3-line-urls
                       button-1-legend-urls
-                      button-2-legend-urls 
-                      button-3-legend-urls)))
+                      button-2-legend-urls
+                      button-3-legend-urls
+											line-width)))
 
-(define gnc:html-linechart? 
+(define gnc:html-linechart?
   (record-predicate <html-linechart>))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;  <html-linechart> class
-;;  generate the <object> form for a linechart. 
+;;  generate the <object> form for a linechart.
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (define gnc:make-html-linechart-internal
   (record-constructor <html-linechart>))
 
 (define (gnc:make-html-linechart)
-  (gnc:make-html-linechart-internal -1 -1 #f #f #f #f '() '() '() 
-				   #f #f #f #f #f #f '() 
-				   #f #f #f #f #f #f))
+  (gnc:make-html-linechart-internal -1 -1 #f #f #f #f '() '() '()
+				   #f #f #f #f #f #f '()
+				   #f #f #f #f #f #f -1 ))
 
 (define gnc:html-linechart-data
   (record-accessor <html-linechart> 'data))
@@ -143,6 +144,7 @@
 (define gnc:html-linechart-set-col-colors!
   (record-modifier <html-linechart> 'col-colors))
 
+
 (define gnc:html-linechart-legend-reversed?
   (record-accessor <html-linechart> 'legend-reversed?))
 
@@ -201,6 +203,12 @@
 (define gnc:html-linechart-set-button-3-legend-urls!
   (record-modifier <html-linechart> 'button-3-legend-urls))
 
+(define gnc:html-linechart-line-width
+  (record-accessor <html-linechart> 'line-width))
+
+(define gnc:html-linechart-set-line-width!
+  (record-modifier <html-linechart> 'line-width))
+
 (define (gnc:html-linechart-append-row! linechart newrow)
   (let ((dd (gnc:html-linechart-data linechart)))
     (set! dd (append dd (list newrow)))
@@ -218,34 +226,34 @@
         (this-row #f)
         (new-row #f))
     ;; find out how many cols are already there in the deepest row
-    (for-each 
+    (for-each
      (lambda (row)
        (let ((l (length row)))
          (if (> l colnum)
              (set! colnum l))))
      rows)
-    
-    ;; append the elements of 'newrow' to the rowumns 
+
+    ;; append the elements of 'newrow' to the rowumns
     (for-each
      (lambda (newelt)
-       ;; find the row, or append one 
+       ;; find the row, or append one
        (if (not (null? rows))
            (begin
              (set! new-row #f)
              (set! this-row (car rows))
              (if (null? (cdr rows))
-                 (set! rows #f)                
+                 (set! rows #f)
                  (set! rows (cdr rows))))
-           (begin 
+           (begin
              (set! new-row #t)
              (set! this-row '())))
-       
-       ;; make sure the rowumn is long enough, then append the data 
+
+       ;; make sure the rowumn is long enough, then append the data
        (let loop ((l (length this-row))
                   (r (reverse this-row)))
          (if (< l colnum)
              (loop (+ l 1) (cons #f r))
-             (set! this-row 
+             (set! this-row
                    (reverse (cons newelt r)))))
        (if new-row
            (gnc:html-linechart-append-row! linechart this-row)
@@ -255,7 +263,7 @@
 
 (define (gnc:not-all-zeros data)
   (define (myor list)
-    (begin 
+    (begin
       (gnc:debug "list" list)
       (if (null? list) #f
 	  (or (car list) (myor (cdr list))))))
@@ -269,16 +277,16 @@
         (this-row #f)
         (new-row #f)
         (rownum 0))
-    (for-each 
+    (for-each
      (lambda (elt)
        (if (not (null? rows))
-           (begin 
+           (begin
              (set! new-row #f)
              (set! this-row (car rows))
              (if (null? (cdr rows))
-                 (set! rows #f)                
+                 (set! rows #f)
                  (set! rows (cdr rows))))
-           (begin 
+           (begin
              (set! new-row #t)
              (set! this-row '())))
        (if new-row
@@ -299,20 +307,20 @@
                  (if (number? n) n 0.0)))))
           ((gnc:gnc-numeric? elt)
            (gnc-numeric-to-double elt))
-          (#t 
+          (#t
            0.0)))
-  
+
   (define (catenate-escaped-strings nlist)
     (if (not (list? nlist))
         ""
         (with-output-to-string
           (lambda ()
-            (for-each 
+            (for-each
              (lambda (s)
-               (let ((escaped 
-                      (regexp-substitute/global 
-                       #f " " 
-                       (regexp-substitute/global 
+               (let ((escaped
+                      (regexp-substitute/global
+                       #f " "
+                       (regexp-substitute/global
                         #f "\\\\" s
                         'pre "\\\\" 'post)
                        'pre "\\ " 'post)))
@@ -325,77 +333,78 @@
          (title (gnc:html-linechart-title linechart))
          (subtitle (gnc:html-linechart-subtitle linechart))
          (url-1
-          (catenate-escaped-strings 
+          (catenate-escaped-strings
            (gnc:html-linechart-button-1-line-urls linechart)))
          (url-2
-          (catenate-escaped-strings 
+          (catenate-escaped-strings
            (gnc:html-linechart-button-2-line-urls linechart)))
          (url-3
-          (catenate-escaped-strings 
+          (catenate-escaped-strings
            (gnc:html-linechart-button-3-line-urls linechart)))
          (legend-1
-          (catenate-escaped-strings 
+          (catenate-escaped-strings
            (gnc:html-linechart-button-1-legend-urls linechart)))
          (legend-2
-          (catenate-escaped-strings 
+          (catenate-escaped-strings
            (gnc:html-linechart-button-2-legend-urls linechart)))
          (legend-3
-          (catenate-escaped-strings 
+          (catenate-escaped-strings
            (gnc:html-linechart-button-3-legend-urls linechart)))
          (x-label (gnc:html-linechart-x-axis-label linechart))
          (y-label (gnc:html-linechart-y-axis-label linechart))
          (data (gnc:html-linechart-data linechart))
 	 (dummy1 (gnc:debug "data " data))
-         (row-labels (catenate-escaped-strings 
+         (row-labels (catenate-escaped-strings
                       (gnc:html-linechart-row-labels linechart)))
-         (col-labels (catenate-escaped-strings 
+         (col-labels (catenate-escaped-strings
                       (gnc:html-linechart-col-labels linechart)))
-         (col-colors (catenate-escaped-strings 
-                      (gnc:html-linechart-col-colors linechart))))
+         (col-colors (catenate-escaped-strings
+                      (gnc:html-linechart-col-colors linechart)))
+				(line-width (gnc:html-linechart-line-width linechart)))
     (if (and (list? data)
              (not (null? data))
 	     (gnc:not-all-zeros data))
-        (begin 
+        (begin
           (push "<object classid=\"")(push GNC-CHART-LINE)(push "\" width=")
           (push (gnc:html-linechart-width linechart))
-          (push " height=") 
+          (push " height=")
           (push (gnc:html-linechart-height linechart))
           (push ">\n")
           (if title
-              (begin 
+              (begin
                 (push "  <param name=\"title\" value=\"")
                 (push title) (push "\">\n")))
           (if subtitle
-              (begin 
+              (begin
                 (push "  <param name=\"subtitle\" value=\"")
                 (push subtitle) (push "\">\n")))
           (if url-1
-              (begin 
+              (begin
                 (push "  <param name=\"line_urls_1\" value=\"")
                 (push url-1)
                 (push "\">\n")))
           (if url-2
-              (begin 
+              (begin
                 (push "  <param name=\"line_urls_2\" value=\"")
                 (push url-2)
                 (push "\">\n")))
           (if url-3
-              (begin 
+              (begin
                 (push "  <param name=\"line_urls_3\" value=\"")
                 (push url-3)
                 (push "\">\n")))
-          (if legend-1 
-              (begin 
+          (if legend-1
+              (begin
                 (push "  <param name=\"legend_urls_1\" value=\"")
                 (push legend-1)
                 (push "\">\n")))
           (if legend-2
-              (begin 
+              (begin
                 (push "  <param name=\"legend_urls_2\" value=\"")
                 (push legend-2)
                 (push "\">\n")))
-          (if legend-3 
-              (begin 
+          (if legend-3
+              (begin
                 (push "  <param name=\"legend_urls_3\" value=\"")
                 (push legend-3)
                 (push "\">\n")))
@@ -405,14 +414,14 @@
                 (push "  <param name=\"data_rows\" value=\"")
                 (push rows) (push "\">\n")
                 (if (list? (car data))
-                    (begin 
+                    (begin
                       (set! cols (length (car data)))
                       (push "  <param name=\"data_cols\" value=\"")
                       (push cols)
-                      (push "\">\n")))           
+                      (push "\">\n")))
                 (push "  <param name=\"data\" value=\"")
                 (let loop ((col 0))
-                  (for-each 
+                  (for-each
                    (lambda (row)
                      (push (ensure-numeric (list-ref-safe row col)))
                      (push " "))
@@ -421,30 +430,33 @@
                       (loop (+ 1 col))))
                 (push "\">\n")))
           (if (and (string? x-label) (> (string-length x-label) 0))
-              (begin 
+              (begin
                 (push "  <param name=\"x_axis_label\" value=\"")
                 (push x-label)
                 (push "\">\n")))
           (if (and (string? y-label) (> (string-length y-label) 0))
-              (begin 
+              (begin
                 (push "  <param name=\"y_axis_label\" value=\"")
                 (push y-label)
                 (push "\">\n")))
           (if (and (string? col-colors) (> (string-length col-colors) 0))
-              (begin 
+              (begin
                 (push "  <param name=\"col_colors\" value=\"")
                 (push col-colors)
                 (push "\">\n")))
           (if (and (string? row-labels) (> (string-length row-labels) 0))
-              (begin 
+              (begin
                 (push "  <param name=\"row_labels\" value=\"")
                 (push row-labels)
                 (push "\">\n")))
           (if (and (string? col-labels) (> (string-length col-labels) 0))
-              (begin 
+              (begin
                 (push "  <param name=\"col_labels\" value=\"")
                 (push col-labels)
                 (push "\">\n")))
+
+
+
 	  (push "  <param name=\"rotate_row_labels\" value=\"")
 	  (push (if (gnc:html-linechart-row-labels-rotated? linechart)
 		    "1\">\n"
@@ -466,12 +478,17 @@
 		    "1\">\n"
 		    "0\">\n"))
 	  (push "  <param name=\"legend_reversed\" value=\"")
+
 	  (push (if (gnc:html-linechart-legend-reversed? linechart)
 		    "1\">\n"
 		    "0\">\n"))
+				(begin
+				(push "  <param name=\"line_width\" value=\"")
+				(push line-width)
+				(push "\">\n"))
           (push "Unable to push line chart\n")
           (push "</object> &nbsp;\n"))
-        (begin 
+        (begin
 	  (gnc:warn "linechart has no non-zero data.")
 	  " "))
     retval))
